
# Surk Dili
Türkçe, ürün oluşturma odaklı, web&mobil&masaüstü desteği planlanan programlama dilidir.

> Shell + Turk -> Surk

# Amaç
Yazılıma başlayan kişilerin yazılım öğrenmeden önce İngilizce öğrenme zorunluluklarını ortadan kaldırarak üzerimizdeki dil kaynaklı handikapları en aza indirmek amacıyla, kurumsal yazılım için kullanılabilecek, modern, güçlü, ürün odaklı bir yazılım dili oluşturmaktır.

Anadili Türkçe olan kişilerin kodlamaya Türkçe ile başlamasıyla birlikte algoritma, veri yapıları, komut setleri, derleyiciler gibi yazılımsal kavramları da kendi anadillerinde öğrenmeleridir.

Kurumsal dünyada aktif olarak kullanılan bir dil ortaya çıkartmak bu projenin amaçları arasındadır.


# Başlarken
1. Aklınızdaki soruları, yaşadığınız teknik sorunlar da dahil olmak üzere [http://sayisalfelsefe.com](http://sayisalfelsefe.com/) adresinde sorabilir ve tartışabilirsiniz.
2. Teknik öneriler ve sorular için issue açabilirsiniz.
3. Bu proje, hiçbir ticari amaç güdülmeden tamamen ücretsiz ve gönüllü olarak, hiçbir sponsorluk ve bağış almadan başlatılmıştır. Kullanılması tamamiyle ücretsizdir.
4. Projenin iyi niyetle ve tamamen karşılıksız olarak başlatıldığını hatırlatır, eleştiri ve öneri dilinize dikkat etmenizi önemle rica ederim. 


# Yükleme

<details><summary>Eğer daha önce yüklemediyseniz öncelikle sisteminize Python3 yükleyiniz.</summary>
<p>


Şurk dili bir Python paketi olarak dağıtılır ve dilin yüklemek için cihazınızda Python yüklü olmalıdır.
Öncelikle şuradaki rehberi takip ederek sisteminize Python3 ü yükleyiniz. İşleminiz tamamlandığında pip 'i de yüklemiş olacaksınız. 

<details><summary>Eğer bash: $: command not found hatası alırsanız ve ne olduğunu bilmiyorsanız buradaki açıklamayı okuyunuz.</summary><p>


$ işareti sizin veri girdiğiniz uç birime girilecek komutun başına temsilen konur. Pek çok anlatımda denk gelirsiniz. Semboliktir. Bunu uçbirime yazmayın. Kopyalarken bu karakteri atlayın.
Burada dikkat etmeniz gereken şey $ işaretini terminale kopyalamamanız gerektiği. Yani;
Komşu şöyle ise; 

    $ sudo apt install python3.6
   Başındaki işareti($) silerek şu şekilde yapıştırınız;
   

    sudo apt install python3.6
</p>
</details>


[Türkçe Python kurulum rehberi](https://tutorial.djangogirls.org/tr/python_installation/)


</p>
</details>


Python3 kullanarak şu komut ile surk derleyicisiniz yükleyiniz;

    pip3 install surk

Sonuç olarak şu komutu uçbirimde(terminal, CMD) yürüttüğünüzde "başarılıyla kuruldu." çıktısını almanız gerekmekte.


> surk --kontrol

Şöyle bir çıktı alıyorsanız her şey hazırdır;

```
 _______           _______  _         
(  ____ \|\     /|(  ____ )| \    /\  
| (    \/| )   ( || (    )||  \  / /  
| (_____ | |   | || (____)||  (_/ /   
(_____  )| |   | ||     __)|   _ (    
      ) || |   | || (\ (   |  ( \ \   
/\____) || (___) || ) \ \__|  /  \ \  
\_______)(_______)|/   \__/|_/    \/  

Surk dili başarıyla kuruldu. Kullanmaya hazırsınız.
```


# Kodlama Rehberi
[Basit kullanımı gösteren kaynak dosyası.](https://github.com/surkdili/surk/blob/master/KAYNAK.md)



# Yol Haritası
Yapılacaklar listesi herkese açık şekilde Trello 'da tutulmaktadır. Aşağıdan ulaşabilirsiniz.


[Yapılacaklar listesi için tıklayınız.](https://trello.com/b/EhRreez1/programlama-dili-yol-haritas%C4%B1)

Kartların açıklamalaları;

Dökümanlar: Kolay ulaşım için linkler.

Bekleyenler(Backlog): Uzun dönemde yapılmak için sıraya konanlar. Buradaki maddeler "Yapılacaklar" ya da "Vazgeçildi" katlarına taşınır.

Yapılacaklar: Kısa vadede yapılması kesinleşmiş maddeler.

Yapılıyor: Şu anda yapılanlar.

Tamamlandı: Tamamlanmı ve yayınlanmış olan işler.

Vazgeçildi: Yapılması düşünülmüş olup sonradan vazgeçilen maddeler ve vazgeçilme sebepleri



# Geri bildirim, Soru, Sorun ve Diğerleri

Eğer bir öneriniz varsa lütfen önce kartların içerisinde arayınız. Eğer kartların içerisinde varsa kart linki ile birlikte o iş için "+1" oy verebilir ya da farklı önerilerde bulunabilirsiniz. 

Eğer takıldığınız bir nokta varsa, bir noktada teknik bir sorun yaşıyorsanız topluluk forumuna sorabilirsiniz; [http://sayisalfelsefe.com/](http://sayisalfelsefe.com/)

Dilin mimarisi, interpreter yapısı gibi daha derin konularda ise issue açabilirsiniz.


### Sevgi ve saygılarımla.

